@@ -5,7 +5,6 @@
 import os
 import re
 import subprocess
-import uuid
 
 
 def _heroku_is_installed() -> bool:
@@ -74,16 +73,91 @@ def _is_git_repository() -> bool:
     return isGitInitialized
 
 
-def _check_file_exists(root_path: os.PathLike, file_name: str):
+def _check_file_exists(root_path: os.PathLike, file_name: str) -> bool:
     """
     Check that a file exists
     """
     path = os.path.join(root_path, file_name)
     if not os.path.exists(path):
-        print(
-            f'dash-tools: deploy-heroku: {file_name} not found in {root_path} - is the project configured for Heroku?')
-        print('dash-tools: deploy-heroku: Procfile, runtime.txt, and requirements.txt are needed for Heroku deployment.')
-        exit('dash-tools: deploy-heroku: Failed')
+        return False
+    return True
+
+
+def _create_requirements_txt(root_path: os.PathLike):
+    """
+    Creates requirements.txt file using pipreqs
+    """
+    print('dash-tools: deploy-heroku: Creating requirements.txt')
+    os.system(f'pipreqs {root_path}')
+
+
+def _create_runtime_txt(root_path: os.PathLike):
+    """
+    Create runtime.txt file
+    Default behavior is to use python-3.8.10
+    """
+    with open(os.path.join(root_path, 'runtime.txt'), 'w') as runtime_file:
+        runtime_file.write('python-3.8.10')
+    print('dash-tools: deploy-heroku: Created runtime.txt using python-3.8.10')
+
+
+def _create_procfile(root_path: os.PathLike, app_name: str):
+    """
+    Create a procfile but prompt the user to verify it before continuing.
+    """
+    with open(os.path.join(root_path, 'Procfile'), 'w') as procfile:
+        procfile.write(
+            f'web: gunicorn --timeout 600 --chdir {app_name} app:server')
+    print(f'dash-tools: deploy-heroku: Created Procfile')
+
+
+def _prompt_user_choice(message: str) -> bool:
+    """
+    Prompt the user to continue or not.
+
+    Returns:
+        True (y/Y)
+        False (n/N)
+    """
+    print(message)
+    response = input('dash-tools: Continue? (y/n) > ')
+    if response.lower() == 'y':
+        return True
+    elif response.lower() == 'n':
+        return False
+    else:
+        return _prompt_user_choice(message)
+
+
+def _check_required_files(root_path: os.PathLike, app_name: str) -> bool:
+    """
+    Check for Procfile, runtime.txt, requirements.txt
+    """
+    print(f'dash-tools: deploy-heroku: Checking for Procfile, runtime.txt, and requirements.txt')
+    deploy_should_continue = True
+    if not _check_file_exists(root_path, 'Procfile'):
+        if _prompt_user_choice(
+                'dash-tools: deploy-heroku: Required file Procfile not found. Create one automatically?'):
+            if _prompt_user_choice(
+                    f'dash-tools: deploy-heroku: Verify that "server = app.server" is declared in {app_name}/app.py! See https://devcenter.heroku.com/articles/procfile'):
+                _create_procfile(root_path, app_name)
+            else:
+                deploy_should_continue = False
+        else:
+            deploy_should_continue = False
+    if (not _check_file_exists(root_path, 'runtime.txt')) and deploy_should_continue:
+        if _prompt_user_choice(
+                'dash-tools: deploy-heroku: Required file runtime.txt not found. Create one automatically?'):
+            _create_runtime_txt(root_path)
+        else:
+            deploy_should_continue = False
+    if (not _check_file_exists(root_path, 'requirements.txt')) and deploy_should_continue:
+        if _prompt_user_choice(
+                'dash-tools: deploy-heroku: Required file requirements.txt not found. Create one automatically?'):
+            _create_requirements_txt(root_path)
+        else:
+            deploy_should_continue = False
+    return deploy_should_continue
 
 
 def _create_app_on_heroku(app_name: str) -> list or None:
@@ -106,19 +180,6 @@ def _create_app_on_heroku(app_name: str) -> list or None:
     return git_remote_url, heroku_command_output
 
 
-def _user_confirmed_deployment(app_name: str) -> bool:
-    """
-    Ask the user if they want to deploy to Heroku
-    """
-    print(
-        f'dash-tools: deploy-heroku: Please confirm creating app "{app_name}" on Heroku and adding git remote "heroku".')
-    user_input = input('dash-tools: deploy-heroku: Confirm? (y/n)\n> ')
-    if user_input == 'y' or user_input == 'Y':
-        return True
-    else:
-        return False
-
-
 def _app_is_not_on_heroku(app_name: str) -> bool:
     """
     Check that the app is not already on Heroku
@@ -156,10 +217,9 @@ def deploy_app_to_heroku(project_root_dir: os.PathLike, app_name: str):
         exit('dash-tools: deploy-heroku: Failed')
 
     # Check that the project has necessary files
-    print(f'dash-tools: deploy-heroku: Checking for Procfile, runtime.txt, and requirements.txt')
-    _check_file_exists(project_root_dir, 'Procfile')
-    _check_file_exists(project_root_dir, 'runtime.txt')
-    _check_file_exists(project_root_dir, 'requirements.txt')
+    if not _check_required_files(project_root_dir, app_name):
+        print('dash-tools: deploy-heroku: Procfile, runtime.txt, and requirements.txt are needed for Heroku deployment.')
+        exit('dash-tools: deploy-heroku: Aborted')
 
     # Log into Heroku
     if not _login_heroku_successful():
@@ -175,15 +235,15 @@ def deploy_app_to_heroku(project_root_dir: os.PathLike, app_name: str):
     print(f'dash-tools: deploy-heroku: Name {app_name} is available!')
 
     # Confirm deployment settings and create the project on Heroku if the user confirms
-    if not _user_confirmed_deployment(app_name):
+    if not _prompt_user_choice(f'dash-tools: deploy-heroku: Please confirm creating app "{app_name}" on Heroku and adding git remote "heroku".'):
         exit('dash-tools: deploy-heroku: Aborted')
 
     # Create the project on Heroku and capture the git remote URL
     git_remote_url, heroku_output = _create_app_on_heroku(app_name)
     if not git_remote_url:
+        print(heroku_output.decode('utf-8'))
         print(
             f'dash-tools: deploy-heroku: Failed to create {app_name} on Heroku!')
-        print(heroku_output.decode('utf-8'))
         exit('dash-tools: deploy-heroku: Failed')
 
     # Add python buildpack
@@ -200,9 +260,10 @@ def deploy_app_to_heroku(project_root_dir: os.PathLike, app_name: str):
     os.system(f'git push heroku master')
 
     print(
-        f'dash-tools: deploy-heroku: Published to git remote: "heroku" on branch "master"')
+        f'dash-tools: deploy-heroku: Published to git remote: "heroku" on branch "master". Push changes to this branch!')
     print(f'dash-tools: deploy-heroku: Successfully deployed to Heroku!')
     print(
         f'dash-tools: deploy-heroku: Management Page https://dashboard.heroku.com/apps/{app_name}')
     print(
-        f'dash-tools: deploy-heroku: Deployed To https://{app_name}.herokuapp.com/')
+        f'dash-tools: deploy-heroku: Deployed to https://{app_name}.herokuapp.com/')
+    print(f'dash-tools: deploy-heroku: Finished!')
